@@ -23,7 +23,6 @@
 -- Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 ----------------------------------------------------------------------*/
 
-#include <assert.h>
 #include <stddef.h>
 #include "glpgel.h"
 #include "glpset.h"
@@ -189,7 +188,7 @@ int build_lu(LU *_lu, MAT *A, double tol, double lim,
          cs, rmax, work);
       if (monit != NULL) monit(lu, 2, 0, 0, 0.0);
       /* compute final factorization A = P*L*U*Q */
-      assert(sizeof(void *) <= sizeof(double));
+      insist(sizeof(void *) <= sizeof(double));
       /* U := P*V*Q, L := P*M*PT, P := P', Q := Q' */
       copy_mat(lu->U, V);
       per_mat(lu->P, lu->U, (void **)work);
