@@ -23,7 +23,6 @@
 -- Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 ----------------------------------------------------------------------*/
 
-#include <assert.h>
 #include <limits.h>
 #include "glpimg.h"
 #include "glpset.h"
@@ -59,7 +58,7 @@ int (*save_img)(IMG *img, char *fname) = save_as_bmp;
 IMG *create_img(int type, int xsize, int ysize)
 {     IMG *img;
       int depth;
-      assert(CHAR_BIT == 8);
+      insist(CHAR_BIT == 8);
       if (!(type == IMG_2 || type == IMG_4 || type == IMG_16 ||
             type == IMG_256))
          fault("create_img: invalid image type");
@@ -94,7 +93,7 @@ IMG *create_img(int type, int xsize, int ysize)
             img->color = 15;
             break;
          default:
-            assert(img->type != img->type);
+            insist(img->type != img->type);
       }
       img->rgb = ucalloc(depth, sizeof(RGB));
       reset_rgb(img);
