@@ -28,17 +28,17 @@
 
 #include "glpset.h"
 
-#define create_avl            glp_create_avl
-#define insert_by_key         glp_insert_by_key
-#define next_node             glp_next_node
-#define prev_node             glp_prev_node
-#define find_by_key           glp_find_by_key
-#define next_by_key           glp_next_by_key
-#define insert_by_pos         glp_insert_by_pos
-#define find_by_pos           glp_find_by_pos
-#define delete_node           glp_delete_node
-#define rotate_avl            glp_rotate_avl
-#define delete_avl            glp_delete_avl
+#define create_avl            _glp_create_avl
+#define insert_by_key         _glp_insert_by_key
+#define next_node             _glp_next_node
+#define prev_node             _glp_prev_node
+#define find_by_key           _glp_find_by_key
+#define next_by_key           _glp_next_by_key
+#define insert_by_pos         _glp_insert_by_pos
+#define find_by_pos           _glp_find_by_pos
+#define delete_node           _glp_delete_node
+#define rotate_avl            _glp_rotate_avl
+#define delete_avl            _glp_delete_avl
 
 typedef struct AVLTREE AVLTREE;
 typedef struct AVLNODE AVLNODE;
