@@ -28,13 +28,13 @@
 
 #include "glprsm.h"
 
-#define bbm1_driver           glp_bbm1_driver
-#define branch_drtom          glp_branch_drtom
-#define branch_first          glp_branch_first
-#define branch_last           glp_branch_last
-#define btrack_bestp          glp_btrack_bestp
-#define btrack_fifo           glp_btrack_fifo
-#define btrack_lifo           glp_btrack_lifo
+#define bbm1_driver           _glp_bbm1_driver
+#define branch_drtom          _glp_branch_drtom
+#define branch_first          _glp_branch_first
+#define branch_last           _glp_branch_last
+#define btrack_bestp          _glp_btrack_bestp
+#define btrack_fifo           _glp_btrack_fifo
+#define btrack_lifo           _glp_btrack_lifo
 
 typedef struct BBDATA BBDATA;
 typedef struct BBNODE BBNODE;
