@@ -28,9 +28,9 @@
 
 #include "glpmat.h"
 
-#define load_hbsm             glp_load_hbsm
-#define free_hbsm             glp_free_hbsm
-#define hbsm_to_mat           glp_hbsm_to_mat
+#define load_hbsm             _glp_load_hbsm
+#define free_hbsm             _glp_free_hbsm
+#define hbsm_to_mat           _glp_hbsm_to_mat
 
 typedef struct HBSM HBSM;
 
