@@ -27,7 +27,7 @@
 #define _GLPK_H
 
 #ifndef _GLPAPI_H
-typedef struct { int dummy; } LPI;
+typedef struct { int _dummy; } LPI;
 #endif
 
 #define GLP_UNDEF    0  /* solution is undefined */
@@ -81,6 +81,9 @@ extern void glp_get_col_bnds(LPI *lp, int j, int *type, double *lb,
 extern int glp_get_col_coef(LPI *lp, int j, int rn[], double aj[]);
 /* get column of constraint matrix */
 
+extern double glp_get_col_fctr(LPI *lp, int j);
+/* query column scale factor */
+
 extern int glp_get_col_kind(LPI *lp, int j);
 /* get column kind */
 
@@ -125,6 +128,9 @@ extern void glp_get_row_bnds(LPI *lp, int i, int *type, double *lb,
 extern int glp_get_row_coef(LPI *lp, int i, int cn[], double ai[]);
 /* get row of constraint matrix */
 
+extern double glp_get_row_fctr(LPI *lp, int i);
+/* query row scale factor */
+
 extern char *glp_get_row_name(LPI *lp, int i);
 /* get row name */
 
@@ -165,10 +171,16 @@ extern LPI *glp_read_lpm1(char *infile, char *outfile);
 extern LPI *glp_read_mps1(char *fname);
 /* read problem data using MPS format */
 
+extern void glp_scale_prob(LPI *lp, int how);
+/* scale problem */
+
 extern void glp_set_col_bnds(LPI *lp, int j, int type, double lb,
       double ub);
 /* set column bounds */
 
+extern void glp_set_col_fctr(LPI *lp, int j, double fctr);
+/* set column scale factor */
+
 extern void glp_set_col_kind(LPI *lp, int j, int kind);
 /* set column kind */
 
@@ -188,9 +200,48 @@ extern void glp_set_row_bnds(LPI *lp, int i, int type, double lb,
       double ub);
 /* set row bounds */
 
+extern void glp_set_row_fctr(LPI *lp, int i, double fctr);
+/* set row scale factor */
+
 extern void glp_set_row_name(LPI *lp, int i, char *name);
 /* assign (change) row name */
 
+struct wmps
+{     /* parameter block of the routine glp_write_mps() */
+      int prob_info;
+      /* if this flag is set, the routine writes several comment cards
+         that contains some information about the problem; otherwise the
+         routine writes no comment cards */
+      int make_obj;
+      /* this parameter controls output objective function row:
+         0 - never output objective function row
+         1 - always output objective function row
+         2 - output objective function row if and only if the problem
+             has no free rows */
+      int use_names;
+      /* if this flag is set, the routine tries to generate standard
+         MPS names using orifinal row and column names as templates;
+         otherwise the routine generates plain names using sequential
+         numbers of rows and columns */
+      int one_entry;
+      /* if this flag is set, the routine keeps fields 5 and 6 empty;
+         otherwise the routine uses all fields */
+      int pedantic;
+      /* if this flag is set, the routine never omits column and vector
+         names; otherwise the routine omits those names every time when
+         it's possible */
+      int skip_empty;
+      /* if this flag is set, the routine writes all columns, including
+         empty ones (i.e. those which have no constraint coefficients);
+         otherwise the routine write only non-empty columns */
+};
+
+extern void glp_init_wmps(struct wmps *parm);
+/* initialize parameter block by default values */
+
+extern int glp_write_mps(LPI *lp, char *fname, struct wmps *parm);
+/* write problem data using MPS format */
+
 struct rsm1
 {     /* revised simplex method parameter block */
       int what;
@@ -318,162 +369,130 @@ extern void glp_init_bbm1(struct bbm1 *parm);
 extern int glp_call_bbm1(LPI *lpi, struct bbm1 *parm);
 /* solve MIP problem using branch-and-bound method */
 
-#ifdef GLP_OLD_API
+struct spx1
+{     /* comprehensive simplex driver parameter block */
+      int form;
+      /* this parameter specifies what form of the basis matrix should
+         be used by the solver:
+         0 - EFI
+         1 - RFI + Bartels & Golub updating technique
+         2 - RFI + Forrest & Tomlin updating technique */
+      int scale;
+      /* this parameter controls the scaling option:
+         0 - do not scale the problem
+         1 - scale the problem using scale factors specified in the
+             problem object */
+      int initb;
+      /* this parameter controls the initial basis option:
+         0 - use the standard basis, where all auxiliary variables are
+             basic and all structural variables are non-basic
+         1 - use the basis specified in the problem object */
+      int feas;
+      /* this parameter specifies by what method the solver should
+         search for primal feasible solution if the initial basis is
+         not primal feasible:
+         0 - use the primal simplex method and implicit artificial
+             variables technique
+         1 - use the dual simplex method and artificial objective
+             function technique */
+      int dual;
+      /* this parameter specifies what the solver should undertake if
+         the initial basis happens to be dual feasible:
+         0 - ignore dual feasibility, i.e. search for primal feasible
+             solution (phase I) and then search for optimal solution
+             (phase II) using the primal simplex method
+         1 - search for optimal solution using the dual simplex method,
+             i.e. skip the phase I */
+      int steep;
+      /* this parameter controls the pricing option (for both primal
+         and dual simplex methods):
+         0 - use the standard ("textbook") pricing
+         1 - use the steepest edge pricing proposed by Goldfarb and
+             Reid */
+      int relax;
+      /* this parameter controls the ratio test option (for both primal
+         and dual simplex methods):
+         0 - use the standard ("textbook") ratio test
+         1 - use two-pass ratio test proposed by P.Harris */
+      int round;
+      /* this parameter controls the final solution rounding option:
+         0 - keep all computed primal and dual values "as is"
+         1 - replace computed primal and dual values, which are close
+             to zero, by exact zeros (this is performed once after the
+             final solution has been obtained) */
+      double tol_bnd;
+      /* relative tolerance which is used to see if the solution is
+         primal feasible */
+      double tol_dj;
+      /* relative tolerance which is used to see if the solution is
+         dual feasible */
+      double tol_piv;
+      /* relative tolerance which is used to choose the pivot element
+         of the simplex table */
+      int max_iter;
+      /* maximal allowable number of simplex iterations; if this
+         parameter is zero, the solver performs no simplex iterations,
+         but reports solution that corresponds to the initial basis */
+      double max_time;
+      /* maximal allowable time of computations, in seconds; if this
+         parameter is zero, the solver performs no simplex iterations,
+         but reports solution that corresponds to the initial basis */
+      double obj_min, obj_max;
+      /* allowable range of the objective function; the solver stops
+         searching as soon as on the phase II the current value of the
+         objective function becomes less than obj_min and continue
+         decreasing or greater than obj_max and continue increasing;
+         to avoid computing the objective function on each simplex
+         iteration, the range (-DBL_MAX, +DBL_MAX) should be used */
+      int quiet;
+      /* this parameter controls displaying informative messages:
+         0 - display all informative messages
+         1 - don't display any informative messages */
+      double delay;
+      /* initial delay interval, in seconds; the solver doesn't display
+         information about current solution the first delay seconds */
+      double freq;
+      /* output frequency, in seconds; the solver displays information
+         about current solution approx. once per freq seconds */
+      int iter_used;
+      /* on entry this parameter is ignored; on exit this parameter is
+         number of actually performed simplex iterations */
+      double time_used;
+      /* on entry this parameter is ignored; on exit this parameter is
+         elapsed time (in seconds) actually spent by the solver */
+};
 
-#define GLP_MAX_NAME 255
-/* maximal length of item name (not including '\0') */
+extern void glp_init_spx1(struct spx1 *parm);
+/* initialize parameter block by default values */
 
-#define GLP_NO       0     /* false */
-#define GLP_YES      1     /* true */
+extern int glp_simplex1(LPI *lp, struct spx1 *_parm);
+/* comprehensive driver to the simplex method */
 
-#define GLP_ROW      101   /* item is row */
-#define GLP_COL      102   /* item is column */
+struct piv1
+{     /* pivoting simplex driver parameter block */
+      int form;
+      /* this parameter specifies what form of the basis matrix should
+         be used by the routine:
+         0 - EFI
+         1 - RFI + Bartels & Golub updating technique
+         2 - RFI + Forrest & Tomlin updating technique */
+      int scale;
+      /* this parameter controls the scaling option:
+         0 - do not scale the constraint matrix
+         1 - scale the constraint matrix using scale factors specified
+             in the problem object */
+      double tol;
+      /* Markowitz tolerance */
+};
 
-#define GLP_FR       201   /* free variable:  -inf <  x[k] <  +inf */
-#define GLP_LO       202   /* lower bound:    l[k] <= x[k] <  +inf */
-#define GLP_UP       203   /* upper bound:    -inf <  x[k] <= u[k] */
-#define GLP_DB       204   /* double bound:   l[k] <= x[k] <= u[k] */
-#define GLP_FX       205   /* fixed variable: l[k]  = x[k]  = u[k] */
+extern void glp_init_piv1(struct piv1 *parm);
+/* initialize parameter block by default values */
 
-#define GLP_MIN      301   /* objective function should be minimized */
-#define GLP_MAX      302   /* objective function should be maximized */
+extern int glp_pivot_in(LPI *lp, int flag[], struct piv1 *parm);
+/* push auxiliary variables into the basis */
 
-#define GLP_INI      311   /* only initial solution is required */
-#define GLP_ANY      312   /* any feasible solution is required */
-#define GLP_FIN      313   /* final solution is required */
-
-#define GLP_BS       501   /* basic variable */
-#define GLP_NL       502   /* non-basic variable on its lower bound */
-#define GLP_NU       503   /* non-basic variable on its upper bound */
-#define GLP_NF       504   /* non-basic free variable */
-#define GLP_NS       505   /* non-basic fixed variable */
-
-#define GLP_EFI      601   /* EFI */
-#define GLP_RFI_BG   602   /* RFI + Bartels & Golub updating tech */
-#define GLP_RFI_FT   603   /* RFI + Forrest & Tomlin updating tech */
-
-#define GLP_FIRST    701   /* branch on the first variable */
-#define GLP_LAST     702   /* branch on the last variable */
-#define GLP_DRTOM    703   /* branch using Driebeek & Tomlin heur */
-
-#define GLP_FIFO     801   /* backtrack using FIFO strategy */
-#define GLP_LIFO     802   /* backtrack using LIFO strategy */
-#define GLP_BESTP    803   /* backtrack using best projection heur */
-
-#define GLP_D_PARS   0x01  /* dump control parameters */
-#define GLP_D_ROWS   0x10  /* dump rows */
-#define GLP_D_RMAT   0x20  /* dump coefficients for each row */
-#define GLP_D_COLS   0x40  /* dump columns */
-#define GLP_D_CMAT   0x80  /* dump coefficients for each column */
-#define GLP_D_ALL    0xFF  /* dump all information */
-
-extern int glp_check_name(char *name);
-/* check symbolic name for correctness */
-
-extern int glp_create_item(int what, char *name);
-/* create new row or column */
-
-extern int glp_dump_ws(char *fname, int what);
-/* dump GLPK API workspace */
-
-extern int glp_find_item(int what, char *name);
-/* find row or column by name */
-
-extern int glp_first_coef(int what);
-/* find the first constraint coefficient */
-
-extern int glp_first_item(int what);
-/* find the first row or column */
-
-extern int glp_get_activity(int what, int *tagx, double *valx,
-      double *dx);
-/* get activity of the current row or column */
-
-extern int glp_get_bounds(int what, int *type, double *lb, double *ub);
-/* get bounds of the current row or column */
-
-extern int glp_get_coef(double *val);
-/* get the current constraint coefficient */
-
-extern int glp_get_cpar(char *name, char *val);
-/* get value of text control parameter */
-
-extern int glp_get_kind(int what, int *kind);
-/* get kind of the current row or column */
-
-extern int glp_get_ipar(char *name, int *val);
-/* get value of integer control parameter */
-
-extern int glp_get_name(int what, char *name);
-/* get name of the current row or column */
-
-extern int glp_get_rpar(char *name, double *val);
-/* get value of real control parameter */
-
-extern int glp_get_seqn(int what, int *seqn);
-/* get seqn attribute of the current row or column */
-
-extern int glp_initialize(void);
-/* initialize GLPK application program interface */
-
-extern int glp_integer(void);
-/* solve MIP problem using branch-and-bound procedure */
-
-extern int glp_interior(void);
-/* solve problem by means of the interior point method */
-
-extern int glp_new_coef(double val);
-/* create new constraint coefficient */
-
-extern int glp_next_coef(int what);
-/* find the next constraint coefficient */
-
-extern int glp_next_item(int what);
-/* find the next row or column */
-
-extern int glp_print_sol(char *fname);
-/* write problem solution using printable format */
-
-extern int glp_read_lpm(char *fname);
-/* read problem data using LPM format */
-
-extern int glp_read_mps(char *fname);
-/* read problem data using MPS format */
-
-extern int glp_set_activity(int what, int tagx, double valx, double dx);
-/* set activity of the current row or column */
-
-extern int glp_set_bounds(int what, int type, double lb, double ub);
-/* set bounds of the current row or column */
-
-extern int glp_set_cpar(char *name, char *val);
-/* set value of text control parameter */
-
-extern int glp_set_ipar(char *name, int val);
-/* set value of integer control parameter */
-
-extern int glp_set_kind(int what, int kind);
-/* set kind of the current row or column */
-
-extern int glp_set_name(int what, char *name);
-/* change name of the current row or column */
-
-extern int glp_set_rpar(char *name, double val);
-/* set value of real control parameter */
-
-extern int glp_set_seqn(int what, int seqn);
-/* set seqn attribute of the current row or column */
-
-extern int glp_simplex(void);
-/* solve problem by means of the revised simplex method */
-
-extern int glp_terminate(void);
-/* terminate GLPK application program interface */
-
-extern int glp_write_mps(char *fname);
-/* write problem data using MPS format */
-
-#endif /* GLP_OLD_API */
+extern int glp_pivot_out(LPI *lp, int flag[], struct piv1 *parm);
+/* pull structural variables from the basis */
 
 #endif
 
