@@ -28,51 +28,51 @@
 
 #include "glpset.h"
 
-#define aat_numb              glp_aat_numb
-#define aat_symb              glp_aat_symb
-#define check_mat             glp_check_mat
-#define check_mplets          glp_check_mplets
-#define check_per             glp_check_per
-#define clear_line            glp_clear_line
-#define clear_mat             glp_clear_mat
-#define copy_mat              glp_copy_mat
-#define copy_per              glp_copy_per
-#define count_nz              glp_count_nz
-#define create_mat            glp_create_mat
-#define create_per            glp_create_per
-#define delete_mat            glp_delete_mat
-#define delete_per            glp_delete_per
-#define eq_scaling            glp_eq_scaling
-#define gm_scaling            glp_gm_scaling
-#define inv_per               glp_inv_per
-#define iper_vec              glp_iper_vec
-#define l_solve               glp_l_solve
-#define load_mat              glp_load_mat
-#define lt_solve              glp_lt_solve
-#define mat_per               glp_mat_per
-#define mat_vec               glp_mat_vec
-#define mprd_numb             glp_mprd_numb
-#define mprd_symb             glp_mprd_symb
-#define new_elem              glp_new_elem
-#define per_mat               glp_per_mat
-#define per_sym               glp_per_sym
-#define per_vec               glp_per_vec
-#define reset_per             glp_reset_per
-#define save_mat              glp_save_mat
-#define scrape_mat            glp_scrape_mat
-#define show_mat              glp_show_mat
-#define sort_mat              glp_sort_mat
-#define submatrix             glp_submatrix
-#define sum_mplets            glp_sum_mplets
-#define sym_vec               glp_sym_vec
-#define test_mat_d            glp_test_mat_d
-#define test_mat_e            glp_test_mat_e
-#define tmat_vec              glp_tmat_vec
-#define trn_mat               glp_trn_mat
-#define u_solve               glp_u_solve
-#define ut_solve              glp_ut_solve
-#define v_solve               glp_v_solve
-#define vt_solve              glp_vt_solve
+#define aat_numb              _glp_aat_numb
+#define aat_symb              _glp_aat_symb
+#define check_mat             _glp_check_mat
+#define check_mplets          _glp_check_mplets
+#define check_per             _glp_check_per
+#define clear_line            _glp_clear_line
+#define clear_mat             _glp_clear_mat
+#define copy_mat              _glp_copy_mat
+#define copy_per              _glp_copy_per
+#define count_nz              _glp_count_nz
+#define create_mat            _glp_create_mat
+#define create_per            _glp_create_per
+#define delete_mat            _glp_delete_mat
+#define delete_per            _glp_delete_per
+#define eq_scaling            _glp_eq_scaling
+#define gm_scaling            _glp_gm_scaling
+#define inv_per               _glp_inv_per
+#define iper_vec              _glp_iper_vec
+#define l_solve               _glp_l_solve
+#define load_mat              _glp_load_mat
+#define lt_solve              _glp_lt_solve
+#define mat_per               _glp_mat_per
+#define mat_vec               _glp_mat_vec
+#define mprd_numb             _glp_mprd_numb
+#define mprd_symb             _glp_mprd_symb
+#define new_elem              _glp_new_elem
+#define per_mat               _glp_per_mat
+#define per_sym               _glp_per_sym
+#define per_vec               _glp_per_vec
+#define reset_per             _glp_reset_per
+#define save_mat              _glp_save_mat
+#define scrape_mat            _glp_scrape_mat
+#define show_mat              _glp_show_mat
+#define sort_mat              _glp_sort_mat
+#define submatrix             _glp_submatrix
+#define sum_mplets            _glp_sum_mplets
+#define sym_vec               _glp_sym_vec
+#define test_mat_d            _glp_test_mat_d
+#define test_mat_e            _glp_test_mat_e
+#define tmat_vec              _glp_tmat_vec
+#define trn_mat               _glp_trn_mat
+#define u_solve               _glp_u_solve
+#define ut_solve              _glp_ut_solve
+#define v_solve               _glp_v_solve
+#define vt_solve              _glp_vt_solve
 
 typedef struct MAT MAT;
 typedef struct ELEM ELEM;
