@@ -36,11 +36,11 @@
 #ifndef _GLPQMD_H
 #define _GLPQMD_H
 
-#define genqmd                glp_genqmd
-#define qmdrch                glp_qmdrch
-#define qmdqt                 glp_qmdqt
-#define qmdupd                glp_qmdupd
-#define qmdmrg                glp_qmdmrg
+#define genqmd                _glp_genqmd
+#define qmdrch                _glp_qmdrch
+#define qmdqt                 _glp_qmdqt
+#define qmdupd                _glp_qmdupd
+#define qmdmrg                _glp_qmdmrg
 
 extern void genqmd(int *neqns, int xadj[], int adjncy[], int perm[],
       int invp[], int deg[], int marker[], int rchset[], int nbrhd[],
