@@ -26,7 +26,6 @@
 #include <stdlib.h>
 #include <string.h>
 #include <time.h>
-#define GLP_OLD_API
 #include "glpk.h"
 #include "glpset.h"
 
@@ -37,9 +36,9 @@
 -- based on the revised simplex method is used.
 ----------------------------------------------------------------------*/
 
-static char *version = "GLPSOL -- GLPK LP/MIP Solver, Version 2.4";
+static char *version = "GLPSOL -- GLPK LP/MIP Solver, Version 3.0";
 
-static char *in_fname = "";
+static char *in_fname = NULL;
 /* name of the input text file */
 
 static int format = 'M';
@@ -50,19 +49,76 @@ static int format = 'M';
 static int check = 0;
 /* if this flag is set, only input data checking is required */
 
+static char *fn_gener = NULL;
+/* name of the output text file, to which the routine glp_read_lpm()
+   should output generated LP/MIP problem in plain text format; NULL
+   means no output */
+
+static int obj_dir = 0;
+/* optimization direction flag:
+    0  - not specified
+   '-' - minimization
+   '+' - maximization */
+
+static int option = 2;
+/* this parameter tells the solver what solution should be found:
+   0 - initial solution
+   1 - primal feasible solution
+   2 - optimal solution */
+
 static int method = 'S';
 /* the method which should be used for solving a problem:
    'S' - simplex method
    'I' - interior point method */
 
-static char *out_fname = "";
+static char *out_fname = NULL;
 /* name of the output text file to which the final solution should be
    sent using printable format (optional) */
 
+static int scale = 1;
+/* if this flag is set, the solver performs automatic scaling the
+   problem before solving; otherwise scaling is not used */
+
+static int form = 1;
+/* this parameter specifies what form of the basis matrix should be used
+   by the solver:
+   0 - EFI
+   1 - RFI + Bartels & Golub updating technique
+   2 - RFI + Forrest & Tomlin updating technique */
+
+static int use_dual = 0;
+/* if this flag is set, the solver uses the dual simplex method for
+   searching for feasible solution; otherwise the solver uses the primal
+   simplex method */
+
+static int steep = 1;
+/* if this flag is set, the solver uses the steepest edge pricing (for
+   both primal and dual simplex) proposed by Goldfarb & Reid; otherwise
+   the solver uses the standard "textbook" pricing */
+
+static int relax = 1;
+/* if this flag is set, the solver uses two-pass ratio test (for both
+   primal and dual simplex) proposed by P.Harris; otherwise the solver
+   uses the standard "textbook" ratio test */
+
 static int nomip = 0;
 /* if this flag is set, the solver considers all integer variables as
    continuous (this allows solving MIP problem as pure LP) */
 
+static int branch = BB_DRTOM;
+/* this parameter specifies what branching technique should be used by
+   the solver:
+   BB_FIRST - branch on the first integer variable
+   BB_LAST  - branch on the last integer variable
+   BB_DRTOM - branch using heuristic by Driebeek and Tomlin */
+
+static int btrack = BB_BESTP;
+/* this parameter specifies what backtracking technique should be used
+   by the solver:
+   BB_FIFO  - backtrack using FIFO heuristic
+   BB_LIFO  - backtrack using LIFO heuristic
+   BB_BESTP - backtrack using the best projection heuristic */
+
 /*----------------------------------------------------------------------
 -- display_help - display help.
 --
@@ -82,8 +138,8 @@ static void display_help(char *my_name)
          " data only");
       print("   --gener filename  send generated LP/MIP problem to file"
          "name using");
-      print("                     plain text format (has sense for --lp"
-         "m only)");
+      print("                     plain text format (has meaning for --"
+         "lpm only)");
       print("   --min             minimize the objective function");
       print("   --max             maximize the objective function");
       print("   --ini             find initial solution only");
@@ -98,11 +154,6 @@ static void display_help(char *my_name)
          "able format");
       print("   --scale           scale the problem (default)");
       print("   --noscale         do not scale the problem");
-      print("   --sum             enable multiplets in constraint matri"
-         "x (will be");
-      print("                     replaced by their sum)");
-      print("   --nosum           disable multiplets in constraint matr"
-         "ix (default)");
       print("   -h, --help        display this help information and exi"
          "t");
       print("   -v, --version     display program version and exit");
@@ -177,40 +228,40 @@ static void display_version(void)
 --
 -- This routine processes parameters specified in command line. */
 
-#define param(str) (strcmp(argv[k], str) == 0)
+#define p(str) (strcmp(argv[k], str) == 0)
 
 static void process_cmdline(int argc, char *argv[])
 {     int k;
       for (k = 1; k < argc; k++)
-      {  if (param("--mps"))
+      {  if (p("--mps"))
             format = 'M';
-         else if (param("--lpm"))
+         else if (p("--lpm"))
             format = 'L';
-         else if (param("--check"))
+         else if (p("--check"))
             check = 1;
-         else if (param("--gener"))
+         else if (p("--gener"))
          {  k++;
             if (k == argc || argv[k][0] == '\0' || argv[k][0] == '-')
             {  error("No gener file name specified");
                exit(EXIT_FAILURE);
             }
-            glp_set_cpar("fn_gener", argv[k]);
+            fn_gener = argv[k];
          }
-         else if (param("--min"))
-            glp_set_ipar("obj_dir", GLP_MIN);
-         else if (param("--max"))
-            glp_set_ipar("obj_dir", GLP_MAX);
-         else if (param("--ini"))
-            glp_set_ipar("option", GLP_INI);
-         else if (param("--any"))
-            glp_set_ipar("option", GLP_ANY);
-         else if (param("--fin"))
-            glp_set_ipar("option", GLP_FIN);
-         else if (param("--simplex"))
+         else if (p("--min"))
+            obj_dir = '-';
+         else if (p("--max"))
+            obj_dir = '+';
+         else if (p("--ini"))
+            option = 0;
+         else if (p("--any"))
+            option = 1;
+         else if (p("--fin"))
+            option = 2;
+         else if (p("--simplex"))
             method = 'S';
-         else if (param("--interior"))
+         else if (p("--interior"))
             method = 'I';
-         else if (param("-o") || param("--output"))
+         else if (p("-o") || p("--output"))
          {  k++;
             if (k == argc || argv[k][0] == '\0' || argv[k][0] == '-')
             {  error("No output file name specified");
@@ -218,59 +269,55 @@ static void process_cmdline(int argc, char *argv[])
             }
             out_fname = argv[k];
          }
-         else if (param("--scale"))
-            glp_set_ipar("scale", GLP_YES);
-         else if (param("--noscale"))
-            glp_set_ipar("scale", GLP_NO);
-         else if (param("--sum"))
-            glp_set_ipar("sum_aij", GLP_YES);
-         else if (param("--nosum"))
-            glp_set_ipar("sum_aij", GLP_NO);
-         else if (param("-h") || param("--help"))
+         else if (p("--scale"))
+            scale = 1;
+         else if (p("--noscale"))
+            scale = 0;
+         else if (p("-h") || p("--help"))
             display_help(argv[0]);
-         else if (param("-v") || param("--version"))
+         else if (p("-v") || p("--version"))
             display_version();
-         else if (param("--textbook"))
-         {  glp_set_ipar("scale", GLP_NO);
-            glp_set_ipar("spx_form", GLP_EFI);
-            glp_set_ipar("spx_use_dual", GLP_NO);
-            glp_set_ipar("spx_steep", GLP_NO);
-            glp_set_ipar("spx_relax", GLP_NO);
-            glp_set_ipar("branch", GLP_FIRST);
-            glp_set_ipar("btrack", GLP_LIFO);
+         else if (p("--textbook"))
+         {  scale = 0;
+            form = 0;
+            use_dual = 0;
+            steep = 0;
+            relax = 0;
+            branch = BB_FIRST;
+            btrack = BB_LIFO;
          }
-         else if (param("--efi"))
-            glp_set_ipar("spx_form", GLP_EFI);
-         else if (param("--rfi-bg"))
-            glp_set_ipar("spx_form", GLP_RFI_BG);
-         else if (param("--rfi-ft"))
-            glp_set_ipar("spx_form", GLP_RFI_FT);
-         else if (param("--primal"))
-            glp_set_ipar("spx_use_dual", GLP_NO);
-         else if (param("--dual"))
-            glp_set_ipar("spx_use_dual", GLP_YES);
-         else if (param("--steep"))
-            glp_set_ipar("spx_steep", GLP_YES);
-         else if (param("--nosteep"))
-            glp_set_ipar("spx_steep", GLP_NO);
-         else if (param("--relax"))
-            glp_set_ipar("spx_relax", GLP_YES);
-         else if (param("--norelax"))
-            glp_set_ipar("spx_relax", GLP_NO);
-         else if (param("--nomip"))
+         else if (p("--efi"))
+            form = 0;
+         else if (p("--rfi-bg"))
+            form = 1;
+         else if (p("--rfi-ft"))
+            form = 2;
+         else if (p("--primal"))
+            use_dual = 0;
+         else if (p("--dual"))
+            use_dual = 1;
+         else if (p("--steep"))
+            steep = 1;
+         else if (p("--nosteep"))
+            steep = 0;
+         else if (p("--relax"))
+            relax = 1;
+         else if (p("--norelax"))
+            relax = 0;
+         else if (p("--nomip"))
             nomip = 1;
-         else if (param("--first"))
-            glp_set_ipar("mip_branch", GLP_FIRST);
-         else if (param("--last"))
-            glp_set_ipar("mip_branch", GLP_LAST);
-         else if (param("--drtom"))
-            glp_set_ipar("mip_branch", GLP_DRTOM);
-         else if (param("--fifo"))
-            glp_set_ipar("mip_btrack", GLP_FIFO);
-         else if (param("--lifo"))
-            glp_set_ipar("mip_btrack", GLP_LIFO);
-         else if (param("--bestp"))
-            glp_set_ipar("mip_btrack", GLP_BESTP);
+         else if (p("--first"))
+            branch = BB_FIRST;
+         else if (p("--last"))
+            branch = BB_LAST;
+         else if (p("--drtom"))
+            branch = BB_DRTOM;
+         else if (p("--fifo"))
+            btrack = BB_FIFO;
+         else if (p("--lifo"))
+            btrack = BB_LIFO;
+         else if (p("--bestp"))
+            btrack = BB_BESTP;
          else if (argv[k][0] == '-' ||
                  (argv[k][0] == '-' && argv[k][1] == '-'))
          {  error("Invalid option `%s'; try %s --help", argv[k],
@@ -278,7 +325,7 @@ static void process_cmdline(int argc, char *argv[])
             exit(EXIT_FAILURE);
          }
          else
-         {  if (in_fname[0] != '\0')
+         {  if (in_fname != NULL)
             {  error("Only one input file allowed");
                exit(EXIT_FAILURE);
             }
@@ -295,27 +342,26 @@ static void process_cmdline(int argc, char *argv[])
 -- solving process. */
 
 int main(int argc, char *argv[])
-{     int option, nc_int, ret;
+{     LPI *lp;
       clock_t t_start;
-      /* initialize GLPK API */
-      glp_initialize();
       /* process command line parameters */
       process_cmdline(argc, argv);
       /* read LP problem data from the input file */
-      if (in_fname[0] == '\0')
+      if (in_fname == NULL)
       {  error("No input file name specified; try %s --help", argv[0]);
          exit(EXIT_FAILURE);
       }
-      glp_get_ipar("option", &option);
       switch (format)
       {  case 'M':
-            if (glp_read_mps(in_fname) != 0)
+            lp = glp_read_mps1(in_fname);
+            if (lp == NULL)
             {  error("MPS file processing error");
                exit(EXIT_FAILURE);
             }
             break;
          case 'L':
-            if (glp_read_lpm(in_fname) != 0)
+            lp = glp_read_lpm1(in_fname, fn_gener);
+            if (lp == NULL)
             {  error("Model description processing error");
                exit(EXIT_FAILURE);
             }
@@ -323,54 +369,74 @@ int main(int argc, char *argv[])
          default:
             insist(format != format);
       }
-      glp_set_ipar("option", option);
+      /* change optimization direction */
+      if (obj_dir != 0) glp_set_obj_sense(lp, obj_dir);
+      /* if only data check is required, skip computations */
       if (check) goto skip;
       /* solve LP/MIP problem */
       t_start = clock();
-      glp_get_ipar("nc_int", &nc_int);
       switch (method)
       {  case 'S':
-            if (nc_int == 0 || nomip)
-               ret = glp_simplex();
+            if (nomip || glp_get_num_int(lp) == 0)
+            {  struct rsm1 parm;
+               glp_init_rsm1(&parm);
+               parm.what = option;
+               parm.form = form;
+               parm.scale = scale;
+               parm.dual = use_dual;
+               parm.steep = steep;
+               parm.relax = relax;
+               glp_call_rsm1(lp, &parm);
+            }
             else
-               ret = glp_integer();
+            {  struct bbm1 parm;
+               glp_init_bbm1(&parm);
+               parm.what = option;
+               parm.branch = branch;
+               parm.btrack = btrack;
+               parm.form = form;
+               parm.scale = scale;
+               parm.dual = use_dual;
+               parm.steep = steep;
+               parm.relax = relax;
+               glp_call_bbm1(lp, &parm);
+            }
             break;
          case 'I':
-            if (nc_int == 0 || nomip)
-               ret = glp_interior();
-            else
-            {  error("Unable to solve MIP problem using interior point "
-                  "method");
+            if (glp_get_num_int(lp) > 0 && !nomip)
+            {  error("Interior point solver is not able to solve MIP pr"
+                  "oblem; use --simplex");
                exit(EXIT_FAILURE);
             }
+            if (option == 0)
+            {  error("Interior point solver is not able to compute init"
+                  "ial basis solution; use --simplex");
+               exit(EXIT_FAILURE);
+            }
+            /* if only primal feasible solution is required, nullify
+               objective function coefficients */
+            if (option == 1)
+            {  int n = glp_get_num_cols(lp), j;
+               for (j = 0; j <= n; j++) glp_set_obj_coef(lp, j, 0.0);
+               glp_set_obj_sense(lp, '-');
+            }
+            glp_call_ipm1(lp);
             break;
          default:
             insist(method != method);
       }
-      switch (ret)
-      {  case 0:
-            break;
-         case 1:
-            error("Unable to solve the problem because of errors");
-            exit(EXIT_FAILURE);
-         case 2:
-            error("Optimization terminated because of solver failure");
-            break;
-         default:
-            insist(ret != ret);
-      }
       /* display statistics */
       print("Time used: %.1f secs",
          (double)(clock() - t_start) / (double)CLOCKS_PER_SEC);
       print("Memory used: %.1fM (%d bytes)",
          (double)mem_tpeak / (1024.0 * 1024.0), mem_tpeak);
-      /* write final solution found by the solver */
-      if (out_fname[0] != '\0' && glp_print_sol(out_fname) != 0)
+      /* write problem solution found by the solver */
+      if (out_fname != NULL && glp_print_soln(lp, out_fname) != 0)
       {  error("Unable to write problem solution");
          exit(EXIT_FAILURE);
       }
-skip: /* terminate GLPK API */
-      glp_terminate();
+skip: /* delete the problem object */
+      glp_delete_prob(lp);
       /* exit to the control program */
       return 0;
 }
